MediaEntityFunctions

Enum MediaEntityFunctions 

pub enum MediaEntityFunctions {
Show 32 variants Unknown, V4L2SubdevUnknown, IoV4L, IoVBI, IoSWRadio, IoDTV, DTVDemod, TSDemux, DTVCondAccess, DTVNetDecap, CAMSensor, Flash, Lens, ATVDecoder, Tuner, IFVIDDecoder, IFAUDDecoder, AudioCapture, AudioPlayback, AudioMixer, ProcVideoComposer, ProcVideoPixelFormatter, ProcVideoPixelEncConv, ProcVideoLUT, ProcVideoScaler, ProcVideoStatistics, ProcVideoEncoder, ProcVideoDecoder, VIDMux, VIDIFBridge, DVDecoder, DVEncoder,
}

Variants



Unknown

Unknown entity. That generally indicates that a driver didn’t initialize properly the entity, which is a Kernel bug



V4L2SubdevUnknown

Unknown entity. That generally indicates that a driver didn’t initialize properly the entity, which is a Kernel bug



IoV4L

Data streaming input and/or output entity.



IoVBI

V4L VBI streaming input or output entity



IoSWRadio

V4L Software Digital Radio (SDR) streaming input or output entity



IoDTV

DVB Digital TV streaming input or output entity



DTVDemod

Digital TV demodulator entity.



TSDemux

MPEG Transport stream demux entity. Could be implemented on hardware or in Kernelspace by the Linux DVB subsystem.



DTVCondAccess

Digital TV Conditional Access module (CAM) entity



DTVNetDecap

Digital TV network ULE/MLE desencapsulation entity. Could be implemented on hardware or in Kernelspace



CAMSensor

Camera video sensor entity.



Flash

Flash controller entity.



Lens

Lens controller entity.



ATVDecoder

Analog video decoder, the basic function of the video decoder is to accept analogue video from a wide variety of sources such as broadcast, DVD players, cameras and video cassette recorders, in either NTSC, PAL, SECAM or HD format, separating the stream into its component parts, luminance and chrominance, and output it in some digital video standard, with appropriate timing signals.



Tuner

Digital TV, analog TV, radio and/or software radio tuner, with consists on a PLL tuning stage that converts radio frequency (RF) signal into an Intermediate Frequency (IF). Modern tuners have internally IF-PLL decoders for audio and video, but older models have those stages implemented on separate entities.



IFVIDDecoder

IF-PLL video decoder. It receives the IF from a PLL and decodes the analog TV video signal. This is commonly found on some very old analog tuners, like Philips MK3 designs. They all contain a tda9887 (or some software compatible similar chip, like tda9885). Those devices use a different I2C address than the tuner PLL.



IFAUDDecoder

IF-PLL sound decoder. It receives the IF from a PLL and decodes the analog TV audio signal. This is commonly found on some very old analog hardware, like Micronas msp3400, Philips tda9840, tda985x, etc. Those devices use a different I2C address than the tuner PLL and should be controlled together with the IF-PLL video decoder.



AudioCapture

Audio Capture Function Entity.



AudioPlayback

Audio Playback Function Entity.



AudioMixer

Audio Mixer Function Entity.



ProcVideoComposer

Video composer (blender). An entity capable of video composing must have at least two sink pads and one source pad, and composes input video frames onto output video frames. Composition can be performed using alpha blending, color keying, raster operations (ROP), stitching or any other means.



ProcVideoPixelFormatter

Video pixel formatter. An entity capable of pixel formatting must have at least one sink pad and one source pad. Read pixel formatters read pixels from memory and perform a subset of unpacking, cropping, color keying, alpha multiplication and pixel encoding conversion. Write pixel formatters perform a subset of dithering, pixel encoding conversion and packing and write pixels to memory.



ProcVideoPixelEncConv

Video pixel encoding converter. An entity capable of pixel enconding conversion must have at least one sink pad and one source pad, and convert the encoding of pixels received on its sink pad(s) to a different encoding output on its source pad(s). Pixel encoding conversion includes but isn’t limited to RGB to/from HSV, RGB to/from YUV and CFA (Bayer) to RGB conversions.



ProcVideoLUT

Video look-up table. An entity capable of video lookup table processing must have one sink pad and one source pad. It uses the values of the pixels received on its sink pad to look up entries in internal tables and output them on its source pad. The lookup processing can be performed on all components separately or combine them for multi-dimensional table lookups.



ProcVideoScaler

Video scaler. An entity capable of video scaling must have at least one sink pad and one source pad, and scale the video frame(s) received on its sink pad(s) to a different resolution output on its source pad(s). The range of supported scaling ratios is entity-specific and can differ between the horizontal and vertical directions (in particular scaling can be supported in one direction only). Binning and sub-sampling (occasionally also referred to as skipping) are considered as scaling.



ProcVideoStatistics

Video statistics computation (histogram, 3A, etc.). An entity capable of statistics computation must have one sink pad and one source pad. It computes statistics over the frames received on its sink pad and outputs the statistics data on its source pad.



ProcVideoEncoder

Video (MPEG, HEVC, VPx, etc.) encoder. An entity capable of compressing video frames. Must have one sink pad and at least one source pad.



ProcVideoDecoder

Video (MPEG, HEVC, VPx, etc.) decoder. An entity capable of decompressing a compressed video stream into uncompressed video frames. Must have one sink pad and at least one source pad.



VIDMux

Video multiplexer. An entity capable of multiplexing must have at least two sink pads and one source pad, and must pass the video frame(s) received from the active sink pad to the source pad.



VIDIFBridge

Video interface bridge. A video interface bridge entity must have at least one sink pad and at least one source pad. It receives video frames on its sink pad from an input video bus of one type (HDMI, eDP, MIPI CSI-2, etc.), and outputs them on its source pad to an output video bus of another type (eDP, MIPI CSI-2, parallel, etc.).



DVDecoder

Digital video decoder. The basic function of the video decoder is to accept digital video from a wide variety of sources and output it in some digital video standard, with appropriate timing signals.



DVEncoder

Digital video encoder. The basic function of the video encoder is to accept digital video from some digital video standard with appropriate timing signals (usually a parallel video bus with sync signals) and output this to a digital video output connector such as HDMI or DisplayPort.