MediaEntityDesc

Struct MediaEntityDesc 

pub struct MediaEntityDesc {
    pub id: EntityId,
    pub name: String,
    pub type: MediaEntityFunctions,
    pub flags: MediaEntityFlags,
    pub pads: usize,
    pub links: usize,
}

Fields

id: EntityId

Entity ID, set by the application. When the ID is or’ed with MEDIA_ENT_ID_FLAG_NEXT, the driver clears the flag and returns the first entity with a larger ID. Do not expect that the ID will always be the same for each instance of the device. In other words, do not hardcode entity IDs in an application.

name: String

Entity name. This name must be unique within the media topology.

type: MediaEntityFunctions

Entity type.

flags: MediaEntityFlags

Entity flags.

pads: usize

Number of pads

links: usize

Total number of outbound links. Inbound links are not counted in this field.

Implementations

Source

impl MediaEntityDesc

pub fn from_fd<F>(fd: F, entity: EntityId) -> Result<Self>
where F: AsRawFd,

pub fn id(&self) -> EntityId

pub fn name(&self) -> &str

pub fn type(&self) -> MediaEntityFunctions

pub fn flags(&self) -> MediaEntityFlags

pub fn pads(&self) -> usize