pub enum LinkType {
DataLink {
source_id: PadId,
sink_id: PadId,
},
InterfaceLink {
source_id: InterfaceId,
sink_id: EntityId,
},
AncillaryLink {
source_id: PadIdOr<InterfaceId>,
sink_id: PadIdOr<EntityId>,
},
}Variants
DataLink
MEDIA_LNK_FL_DATA_LINK On pad to pad links: unique IDs for the source/sink pad.
InterfaceLink
MEDIA_LNK_FL_INTERFACE_LINK On interface to entity links: unique IDs for the interface/entity.
AncillaryLink
MEDIA_LNK_FL_ANCILLARY_LINK for links that represent a physical relationship between two entities. The link may or may not be immutable, so applications must not assume either case.