MediaPadFlags

Enum MediaPadFlags 

pub enum MediaPadFlags {
    Sink,
    Source,
    SinkMustConnect,
    SourceMustConnect,
}

Variants



Sink

Input pad, relative to the entity. Input pads sink data and are targets of links.



Output pad, relative to the entity. Output pads source data and are origins of links.



SinkMustConnect

The pad is an input pad and the pad is linked to any other pad, then at least one of those links must be enabled for the entity to be able to stream. There could be temporary reasons (e.g. device configuration dependent) for the pad to need enabled links even when this flag isn’t set; the absence of the flag doesn’t imply there is none.



SourceMustConnect

The pad is an output pad and the pad is linked to any other pad, then at least one of those links must be enabled for the entity to be able to stream. There could be temporary reasons (e.g. device configuration dependent) for the pad to need enabled links even when this flag isn’t set; the absence of the flag doesn’t imply there is none.