pub struct MediaEntityDesc {
pub id: EntityId,
pub name: String,
pub type: MediaEntityFunctions,
pub flags: MediaEntityFlags,
pub pads: usize,
pub links: usize,
}Fields
id: EntityIdEntity ID, set by the application. When the ID is or’ed with MEDIA_ENT_ID_FLAG_NEXT, the driver clears the flag and returns the first entity with a larger ID. Do not expect that the ID will always be the same for each instance of the device. In other words, do not hardcode entity IDs in an application.
name: StringEntity name. This name must be unique within the media topology.
type: MediaEntityFunctionsEntity type.
flags: MediaEntityFlagsEntity flags.
pads: usizeNumber of pads
links: usizeTotal number of outbound links. Inbound links are not counted in this field.
Implementations
Sourceimpl MediaEntityDesc
impl MediaEntityDesc
pub fn from_fd<F>(fd: F, entity: EntityId) -> Result<Self>where
F: AsRawFd,
pub fn id(&self) -> EntityId
pub fn name(&self) -> &str
pub fn type(&self) -> MediaEntityFunctions
pub fn flags(&self) -> MediaEntityFlags
pub fn pads(&self) -> usize
pub fn links(&self) -> usize